@@ -1432,7 +1432,7 @@ cast(LDOUBLE value)
      * comparison (cf. C99: 6.3.1.4, 2).  It might then equal the LDOUBLE
      * value although converting the latter to UINTMAX_T would overflow.
      */
-    if (value >= UINTMAX_MAX)
+    if (value >= (double)UINTMAX_MAX)
         return UINTMAX_MAX;
 
     result = value;
