@@ -46,6 +46,7 @@ static void checkReturnFlag_KINLS(int flag, const char *functionName);
 static void checkReturnFlag_IDA(int flag, const char *functionName);
 static void checkReturnFlag_IDALS(int flag, const char *functionName);
 static void checkReturnFlag_SUNLS(int flag, const char *functionName);
+static void checkReturnFlag_SUNMatrix(int flag, const char *functionName);
 #endif
 
 /**
@@ -90,6 +91,9 @@ void checkReturnFlag_SUNDIALS(int flag, sundialsFlagType type,
   case SUNDIALS_SUNLS_FLAG:
     checkReturnFlag_SUNLS(flag, functionName);
     break;
+  case SUNDIALS_MATRIX_FLAG:
+    checkReturnFlag_SUNMatrix(flag, functionName);
+    break;
 #endif
   default:
     throwStreamPrint(NULL, "In function checkReturnFlag_SUNDIALS: Invalid sundialsFlagType %u.", type);
@@ -112,7 +116,7 @@ static void checkReturnFlag_CV(int flag, const char *functionName) {
     case CV_ROOT_RETURN:
       break;
     case CV_WARNING:
-      warningStreamPrint(LOG_STDOUT, 0, "##CVODE## %s In function %s: Got some warning.", flagName, functionName);
+      warningStreamPrint(OMC_LOG_STDOUT, 0, "##CVODE## %s In function %s: Got some warning.", flagName, functionName);
       break;
     case CV_TOO_MUCH_WORK:
       throwStreamPrint(NULL, "##CVODE## %s In function %s: The solver took maximum number of internal steps but could not reach tout.", flagName, functionName);
@@ -249,6 +253,33 @@ static void checkReturnFlag_CVLS(int flag, const char *functionName) {
   }
 }
 
+/**
+ * @brief Error handler function for CVODE
+ *
+ * @param errorCode   Error code from CVODE
+ * @param module      Name of the CVODE module reporting the error.
+ * @param function    Name of the function in which the error occurred.
+ * @param msg         Error Message.
+ * @param userData    Pointer to user data given with CVodeSetUserData.
+ */
+void cvodeErrorHandlerFunction(int errorCode, const char *module,
+                               const char *function, char *msg, void *userData)
+{
+  /* Variables */
+  CVODE_SOLVER* cvodeData;
+  DATA* data;
+
+  if (userData != NULL && OMC_ACTIVE_STREAM(OMC_LOG_SOLVER)) {
+    cvodeData = (CVODE_SOLVER*) userData;
+    data = (DATA*)cvodeData->simData->data;
+
+    infoStreamPrint(OMC_LOG_SOLVER, 1, "#### CVODE error message #####");
+    infoStreamPrint(OMC_LOG_SOLVER, 0, " -> error code %d\n -> module %s\n -> function %s", errorCode, module, function);
+    infoStreamPrint(OMC_LOG_SOLVER, 0, " Message: %s", msg);
+    messageClose(OMC_LOG_SOLVER);
+  }
+}
+
 #ifndef OMC_FMI_RUNTIME
 /**
  * @brief Checks given KINSOL flag and reports potential error.
@@ -266,7 +297,7 @@ static void checkReturnFlag_KIN(int flag, const char *functionName) {
   case KIN_STEP_LT_STPTOL:
     break;
   case KIN_WARNING:
-    warningStreamPrint(LOG_STDOUT, 0,
+    warningStreamPrint(OMC_LOG_STDOUT, 0,
                        "##KINSOL## %s In function %s: Got some warning.", flagName, functionName);
     break;
   case KIN_MEM_NULL:
@@ -411,19 +442,23 @@ static void checkReturnFlag_KINLS(int flag, const char *functionName) {
 }
 
 /**
- * @brief Checks given IDA flag and reports potential error.
+ * @brief Checks given IDA/IDAS flag and reports potential error.
  *
- * @param flag          Return value of Kinsol routine.
+ * Throws on errors.
+ *
+ * TODO: Make it optionla to throw error and only report error instead.
+ *
+ * @param flag          Return value of IDA routine.
  * @param functionName  Name of IDA function that returned the flag.
  */
 static void checkReturnFlag_IDA(int flag, const char *functionName) {
   switch (flag) {
-  case IDA_SUCCESS:
-  case IDA_TSTOP_RETURN:
-  case IDA_ROOT_RETURN:
+  case IDA_SUCCESS:       /* Successful function return. */
+  case IDA_TSTOP_RETURN:  /* IDASolve succeeded by reaching the specified stopping point. */
+  case IDA_ROOT_RETURN:   /* IDASolve succeeded and found one or more roots. */
     break;
   case IDA_WARNING:
-    warningStreamPrint(LOG_STDOUT, 0,
+    warningStreamPrint(OMC_LOG_STDOUT, 0,
                        "##IDA## In function %s: Got some warning.",
                        functionName);
     break;
@@ -486,7 +521,7 @@ static void checkReturnFlag_IDA(int flag, const char *functionName) {
     break;
   case IDA_RTFUNC_FAIL:
     throwStreamPrint(NULL,
-                     "##IDA## In function %s: The rootnding function failed "
+                     "##IDA## In function %s: The rootfinding function failed "
                      "in an unrecoverable manner.",
                      functionName);
     break;
@@ -499,7 +534,7 @@ static void checkReturnFlag_IDA(int flag, const char *functionName) {
   case IDA_FIRST_RES_FAIL:
     throwStreamPrint(NULL,
                      "##IDA## In function %s: The user-provided residual "
-                     "function failed recoverably on the rst call.",
+                     "function failed recoverably on the first call.",
                      functionName);
     break;
   case IDA_LINESEARCH_FAIL:
@@ -570,6 +605,75 @@ static void checkReturnFlag_IDA(int flag, const char *functionName) {
                      "##IDA## In function %s: The vector argument where derivative should be stored is NULL.",
                      functionName);
     break;
+  case IDA_NO_QUAD:
+    throwStreamPrint(NULL,
+                     "##IDA## In function %s: Quadratures were not initialized.",
+                     functionName);
+    break;
+  case IDA_QRHS_FAIL:
+    throwStreamPrint(NULL,
+                     "##IDA## In function %s: The user-provided right-hand side function for quadratures "
+                     "failed in an unrecoverable manner.",
+                     functionName);
+    break;
+  case IDA_FIRST_QRHS_ERR:
+    throwStreamPrint(NULL,
+                     "##IDA## In function %s: The user-provided right-hand side function for quadratures "
+                     "failed in an unrecoverable manner on the first call.",
+                     functionName);
+    break;
+  case IDA_REP_QRHS_ERR:
+    throwStreamPrint(NULL,
+                     "##IDA## In function %s: The user-provided right-hand side repeatedly returned "
+                     "a recoverable error flag, but the solver was unable to recover.",
+                     functionName);
+    break;
+  case IDA_NO_SENS:
+    throwStreamPrint(NULL,
+                     "##IDA## In function %s: Sensitivities were not initialized.",
+                     functionName);
+    break;
+  case IDA_SRES_FAIL:
+    throwStreamPrint(NULL,
+                     "##IDA## In function %s: The user-provided sensitivity residual function failed "
+                     "in an unrecoverable manner.",
+                     functionName);
+    break;
+  case IDA_REP_SRES_ERR:
+    throwStreamPrint(NULL,
+                     "##IDA## In function %s: The user-provided sensitivity residual function repeatedly "
+                     "returned a recoverable error flag, but the solver was unable to recover.",
+                     functionName);
+    break;
+  case IDA_BAD_IS:
+    throwStreamPrint(NULL,
+                     "##IDA## In function %s: The sensitivity identifier is not valid.",
+                     functionName);
+    break;
+  case IDA_NO_QUADSENS:
+    throwStreamPrint(NULL,
+                     "##IDA## In function %s: Sensitivity-dependent quadratures were not initialized.",
+                     functionName);
+    break;
+  case IDA_QSRHS_FAIL:
+    throwStreamPrint(NULL,
+                     "##IDA## In function %s: The user-provided sensitivity-dependent quadrature "
+                     "righthand side function failed in an unrecoverable manner.",
+                     functionName);
+    break;
+  case IDA_FIRST_QSRHS_ERR:
+    throwStreamPrint(NULL,
+                     "##IDA## In function %s: The user-provided sensitivity-dependent quadrature "
+                     "righthand side function failed in an unrecoverable manner on the first call.",
+                     functionName);
+    break;
+  case IDA_REP_QSRHS_ERR:
+    throwStreamPrint(NULL,
+                     "##IDA## In function %s: The user-provided sensitivity-dependent quadrature "
+                     "righthand side repeatedly returned a recoverable error flag, but the solver "
+                     "was unable to recover.",
+                     functionName);
+    break;
   default:
     throwStreamPrint(NULL,
                      "##IDA## In function %s: Error with flag %i.",
@@ -648,8 +752,8 @@ static void checkReturnFlag_IDALS(int flag, const char *functionName) {
 /**
  * @brief Checks given SUNLS flag and reports potential error.
  *
- * @param flag          Return value of Kinsol routine.
- * @param functionName  Name of Kinsol function that returned the flag.
+ * @param flag          Return value of SUNLS routine.
+ * @param functionName  Name of SUNLS function that returned the flag.
  */
 static void checkReturnFlag_SUNLS(int flag, const char *functionName) {
   switch (flag) {
@@ -752,6 +856,43 @@ static void checkReturnFlag_SUNLS(int flag, const char *functionName) {
   }
 }
 
+/**
+ * @brief Checks given SUNMatrix flag and reports potential error.
+ *
+ * @param flag          Return value of SUNMatrix routine.
+ * @param functionName  Name of SUNMatrix function that returned the flag.
+ */
+static void checkReturnFlag_SUNMatrix(int flag, const char *functionName) {
+  switch (flag) {
+  case SUNMAT_SUCCESS:
+    break;
+  case SUNMAT_ILL_INPUT:
+    throwStreamPrint(NULL,
+                     "##SUNMatrix## In function %s: Illegal function input.",
+                     functionName);
+    break;
+  case SUNMAT_MEM_FAIL:
+    throwStreamPrint(NULL,
+                     "##SUNMatrix## In function %s: Failed memory access/alloc.",
+                     functionName);
+    break;
+  case SUNMAT_OPERATION_FAIL:
+    throwStreamPrint(NULL,
+                     "##SUNMatrix## In function %s: A SUNMatrix operation returned nonzero.",
+                     functionName);
+    break;
+  case SUNMAT_MATVEC_SETUP_REQUIRED:
+    throwStreamPrint(NULL,
+                     "##SUNMatrix## In function %s: The SUNMatMatvecSetup routine needs to be called.",
+                     functionName);
+    break;
+  default:
+    throwStreamPrint(NULL,
+                     "##SUNMatrix## In function %s: Error with flag %i.",
+                     functionName, flag);
+  }
+}
+
 /**
  * @brief Debug print function for CSC SunMatrix
  *
@@ -772,12 +913,12 @@ void sundialsPrintSparseMatrix(SUNMatrix A, const char* name, const int logLevel
   assertStreamPrint(NULL, NULL != SM_DATA_S(A), "matrix data is NULL pointer");
 
   if (SM_SPARSETYPE_S(A) != CSC_MAT) {
-    errorStreamPrint(LOG_STDOUT, 0,
+    errorStreamPrint(OMC_LOG_STDOUT, 0,
                      "In function sundialsPrintSparseMatrix: Wrong sparse format "
                      "of SUNMatrix A%s.", name);
   }
 
-  if (ACTIVE_STREAM(logLevel)) {
+  if (OMC_ACTIVE_STREAM(logLevel)) {
     nnz = SUNSparseMatrix_NNZ(A);
     np = SM_NP_S(A);
     columns = SUNSparseMatrix_Columns(A);
@@ -832,6 +973,33 @@ void sundialsPrintSparseMatrix(SUNMatrix A, const char* name, const int logLevel
   }
 }
 
+/**
+ * @brief Error handler function for IDA
+ *
+ * @param errorCode   Error code from IDA
+ * @param module      Name of the IDA module reporting the error.
+ * @param function    Name of the function in which the error occurred.
+ * @param msg         Error Message.
+ * @param userData    Pointer to user data given with IDASetUserData.
+ */
+void idaErrorHandlerFunction(int errorCode, const char *module,
+                             const char *function, char *msg, void *userData)
+{
+  /* Variables */
+  IDA_SOLVER* idaData;
+  DATA* data;
+
+  if (userData != NULL && OMC_ACTIVE_STREAM(OMC_LOG_SOLVER)) {
+    idaData = (IDA_SOLVER*) userData;
+    data = (DATA*)idaData->userData->data;
+
+    infoStreamPrint(OMC_LOG_SOLVER, 1, "#### IDA error message #####");
+    infoStreamPrint(OMC_LOG_SOLVER, 0, " -> error code %d\n -> module %s\n -> function %s", errorCode, module, function);
+    infoStreamPrint(OMC_LOG_SOLVER, 0, " Message: %s", msg);
+    messageClose(OMC_LOG_SOLVER);
+  }
+}
+
 /**
  * @brief Error handler function given to KINSOL.
  *
@@ -839,53 +1007,53 @@ void sundialsPrintSparseMatrix(SUNMatrix A, const char* name, const int logLevel
  * @param module      Name of the KINSOL module reporting the error.
  * @param function    Name of the function in which the error occurred.
  * @param msg         Error Message.
- * @param userData    Pointer to user data given with KINSetErrHandlerFn.
+ * @param userData    Pointer to user data given with KINSetUserData.
  */
-void kinsolErrorHandlerFunction(int errorCode, const char *module,
-                                const char *function, char *msg,
-                                void *userData) {
+void kinsolErrorHandlerFunction(int errorCode, const char* module,
+                                const char *function, char* msg,
+                                void* userData) {
   /* Variables */
-  NLS_KINSOL_DATA *kinsolData;
-  DATA *data;
-  int sysNumber;
+  NLS_KINSOL_DATA* kinsolData;
+  DATA* data;
+  NONLINEAR_SYSTEM_DATA* nlsData;
   long eqSystemNumber;
 
   if (userData != NULL) {
     kinsolData = (NLS_KINSOL_DATA *)userData;
-    data = kinsolData->userData.data;
-    sysNumber = kinsolData->userData.sysNumber;
-    if (sysNumber > 0) {
-      eqSystemNumber = data->simulationInfo->nonlinearSystemData[sysNumber].equationIndex;
+    data = kinsolData->userData->data;
+    nlsData = kinsolData->userData->nlsData;
+    if (nlsData) {
+      eqSystemNumber = nlsData->equationIndex;
     } else {
       eqSystemNumber = -1;
     }
   }
 
-  if (ACTIVE_STREAM(LOG_NLS)) {
+  if (OMC_ACTIVE_STREAM(OMC_LOG_NLS)) {
     if (userData != NULL && eqSystemNumber > 0) {
       warningStreamPrint(
-          LOG_NLS, 1, "kinsol failed for system %d",
+          OMC_LOG_NLS, 1, "kinsol failed for system %d",
           modelInfoGetEquation(&data->modelData->modelDataXml, eqSystemNumber).id);
     } else {
       warningStreamPrint(
-          LOG_NLS, 1, "kinsol failed");
+          OMC_LOG_NLS, 1, "kinsol failed");
     }
 
-    warningStreamPrint(LOG_NLS, 0,
+    warningStreamPrint(OMC_LOG_NLS, 0,
                        "[module] %s | [function] %s | [error_code] %d", module,
                        function, errorCode);
     if (msg) {
-      warningStreamPrint(LOG_NLS, 0, "%s", msg);
+      warningStreamPrint(OMC_LOG_NLS, 0, "%s", msg);
     }
 
-    messageClose(LOG_NLS);
+    messageClose(OMC_LOG_NLS);
   }
 }
 
 /**
  * @brief Info handler function given to KINSOL.
  *
- * Will only print information when stream LOG_NLS_V is active.
+ * Will only print information when stream OMC_LOG_NLS_V is active.
  *
  * @param module      Name of the KINSOL module reporting the information.
  * @param function    Name of the function reporting the information.
@@ -894,15 +1062,15 @@ void kinsolErrorHandlerFunction(int errorCode, const char *module,
  */
 void kinsolInfoHandlerFunction(const char *module, const char *function,
                                char *msg, void *user_data) {
-  UNUSED(user_data);  /* DIsables compiler warning */
+  UNUSED(user_data);  /* Disables compiler warning */
 
-  if (ACTIVE_STREAM(LOG_NLS_V)) {
-    warningStreamPrint(LOG_NLS_V, 1, "[module] %s | [function] %s:", module, function);
+  if (OMC_ACTIVE_STREAM(OMC_LOG_NLS_V)) {
+    warningStreamPrint(OMC_LOG_NLS_V, 1, "[module] %s | [function] %s:", module, function);
     if (msg) {
-      warningStreamPrint(LOG_NLS_V, 0, "%s", msg);
+      warningStreamPrint(OMC_LOG_NLS_V, 0, "%s", msg);
     }
 
-    messageClose(LOG_NLS_V);
+    messageClose(OMC_LOG_NLS_V);
   }
 }
 #endif /* #ifndef OMC_FMI_RUNTIME */
@@ -949,15 +1117,4 @@ void kinsolInfoHandlerFunction(const char *module, const char *function,
   throwStreamPrint(NULL, "No sundials/kinsol support activated.");
 }
 
-/**
- * @brief  Function not supported without WITH_SUNDIALS
- *
- * @param A
- * @param name
- * @param logLevel
- */
-void sundialsPrintSparseMatrix(SUNMatrix A, const char* name, const int logLevel) {
-  throwStreamPrint(NULL, "No sundials/kinsol support activated.");
-}
-
 #endif /* WITH_SUNDIALS */
