@@ -233,7 +233,7 @@ DocumentationWidget::DocumentationWidget(QWidget *pParent)
   mpSubscriptAction->setStatusTip(tr("Type very small letters just below the line of text"));
   mpSubscriptAction->setCheckable(true);
 #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
-  // TODO: ToggleSubscript
+  connect(mpSubscriptAction, SIGNAL(triggered()), SLOT(subscript()));
 #else
   connect(mpSubscriptAction, SIGNAL(triggered()), mpHTMLEditor->pageAction(QWebPage::ToggleSubscript), SLOT(trigger()));
 #endif
@@ -242,7 +242,7 @@ DocumentationWidget::DocumentationWidget(QWidget *pParent)
   mpSuperscriptAction->setStatusTip(tr("Type very small letters just above the line of text"));
   mpSuperscriptAction->setCheckable(true);
 #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
-  // TODO: ToggleSuperscript
+  connect(mpSuperscriptAction, SIGNAL(triggered()), SLOT(superscript()));
 #else
   connect(mpSuperscriptAction, SIGNAL(triggered()), mpHTMLEditor->pageAction(QWebPage::ToggleSuperscript), SLOT(trigger()));
 #endif
@@ -393,6 +393,11 @@ DocumentationWidget::DocumentationWidget(QWidget *pParent)
   mpEditorToolBar->addAction(mpUnLinkAction);
   // update the actions whenever the selectionChanged signal is raised.
   connect(mpHTMLEditor->page(), SIGNAL(selectionChanged()), SLOT(updateActions()));
+#ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+  // Qt webengine editing works only when we have a selection.
+  // Call updateActions() to disable all actions since there is not selection yet.
+  updateActions();
+#endif // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
   // add a layout to html editor widget
   QVBoxLayout *pHTMLWidgetLayout = new QVBoxLayout;
   pHTMLWidgetLayout->setAlignment(Qt::AlignTop);
@@ -404,11 +409,6 @@ DocumentationWidget::DocumentationWidget(QWidget *pParent)
   // create the HTMLEditor
   mpHTMLSourceEditor = new HTMLEditor(this);
   mpHTMLSourceEditor->hide();
-#ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
-  // TODO: contentsChanged
-#else
-  connect(mpHTMLEditor->page(), SIGNAL(contentsChanged()), SLOT(updateHTMLSourceEditor()));
-#endif
   HTMLHighlighter *pHTMLHighlighter = new HTMLHighlighter(OptionsDialog::instance()->getHTMLEditorPage(), mpHTMLSourceEditor->getPlainTextEdit());
   connect(OptionsDialog::instance(), SIGNAL(HTMLEditorSettingsChanged()), pHTMLHighlighter, SLOT(settingsChanged()));
   // eidtors widget layout
@@ -559,6 +559,40 @@ void DocumentationWidget::execCommand(const QString &command, const QString &val
 #endif
 }
 
+#ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+struct JavaScriptResult {
+  QVariant result;
+  bool finished;
+  JavaScriptResult() : result(QVariant("")), finished(false) {}
+  JavaScriptResult(JavaScriptResult *pJavaScriptResult) : result(pJavaScriptResult->result), finished(pJavaScriptResult->finished) {}
+  ~JavaScriptResult() {}
+  bool isFinished() {return finished;}
+};
+
+struct JavascriptResultFunctor {
+  JavaScriptResult *mpJavaScriptResult;
+  JavascriptResultFunctor(JavaScriptResult *pJavaScriptResult) : mpJavaScriptResult(pJavaScriptResult) {}
+  void operator()(const QVariant &result) {
+    mpJavaScriptResult->result.setValue(result);
+    mpJavaScriptResult->finished = true;
+  }
+};
+
+QVariant DocumentationWidget::runJavaScript(const QString &javaScript)
+{
+  JavaScriptResult *pJavaScriptResult = new JavaScriptResult();
+  QDeadlineTimer deadline(10000); // 10 seconds
+  QWebEnginePage *pWebPage = mpHTMLEditor->page();
+  pWebPage->runJavaScript(javaScript, JavascriptResultFunctor(pJavaScriptResult));
+  while (!pJavaScriptResult->isFinished() && !deadline.hasExpired()) {
+    QCoreApplication::processEvents();
+  }
+  QVariant result = pJavaScriptResult->result;
+  delete pJavaScriptResult;
+  return result;
+}
+#endif // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+
 /*!
  * \brief DocumentationWidget::queryCommandState
  * Calls the document.queryCommandState API.\n
@@ -571,9 +605,8 @@ bool DocumentationWidget::queryCommandState(const QString &commandName)
   QString javaScript = QString("document.queryCommandState(\"%1\")").arg(commandName);
   QVariant result;
 #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
-  QWebEnginePage *pWebPage = mpHTMLEditor->page();
-  pWebPage->runJavaScript(javaScript, [&](const QVariant & arg){ result = arg; });
-#else
+  result = runJavaScript(javaScript);
+#else // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
   QWebFrame *pWebFrame = mpHTMLEditor->page()->mainFrame();
   result = pWebFrame->evaluateJavaScript(javaScript);
 #endif
@@ -592,9 +625,8 @@ QString DocumentationWidget::queryCommandValue(const QString &commandName)
   QString javaScript = QString("document.queryCommandValue(\"%1\")").arg(commandName);
   QVariant result;
 #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
-  QWebEnginePage *pWebPage = mpHTMLEditor->page();
-  pWebPage->runJavaScript(javaScript, [&](const QVariant & arg){ result = arg; });
-#else
+  result = runJavaScript(javaScript);
+#else // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
   QWebFrame *pWebFrame = mpHTMLEditor->page()->mainFrame();
   result = pWebFrame->evaluateJavaScript(javaScript);
 #endif
@@ -724,8 +756,7 @@ bool DocumentationWidget::isLinkSelected()
                                "isLinkSelected()");
   QVariant result;
 #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
-  QWebEnginePage *pWebPage = mpHTMLEditor->page();
-  pWebPage->runJavaScript(javaScript, [&](const QVariant & arg){ result = arg; });
+  result = runJavaScript(javaScript);
 #else
   QWebFrame *pWebFrame = mpHTMLEditor->page()->mainFrame();
   result = pWebFrame->evaluateJavaScript(javaScript);
@@ -763,6 +794,104 @@ bool DocumentationWidget::removeDocumentationHistory(LibraryTreeItem *pLibraryTr
   return removed;
 }
 
+/*!
+ * \brief DocumentationWidget::updateHTMLSourceEditor
+ * Updates the contents of the HTML source editor.
+ */
+void DocumentationWidget::updateHTMLSourceEditor()
+{
+#ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+  QEventLoop eventLoop;
+  QTimer timer;
+  connect(&timer, SIGNAL(timeout()), &eventLoop, SLOT(quit()));
+  PlainTextEdit *textEdit = mpHTMLSourceEditor->getPlainTextEdit();
+  mpHTMLEditor->page()->toHtml([&](const QString &result){
+    textEdit->setPlainText(result);
+    eventLoop.quit();
+  });
+  /* Just in case toHtml response doesn't arrive for some reason we don't want to stay in blocked state.
+   * So we start a timer which will quit the event loop after 5 secs.
+   */
+  timer.start(5000);
+  eventLoop.exec();
+  // Remove contenteditable="true".
+  QString contents = textEdit->toPlainText();
+  contents.remove(" contenteditable=\"true\"");
+  textEdit->setPlainText(contents);
+#else // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+  mpHTMLSourceEditor->getPlainTextEdit()->setPlainText(mpHTMLEditor->page()->mainFrame()->toHtml());
+#endif // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+}
+
+/*!
+ * \brief DocumentationWidget::updateActionsHelper
+ * Helper function for DocumentationWidget::updateActions
+ */
+void DocumentationWidget::updateActionsHelper()
+{
+  bool state = mpStyleComboBox->blockSignals(true);
+  QString format = queryCommandValue("formatBlock");
+  int currentIndex = mpStyleComboBox->findData(format);
+  if (currentIndex > -1) {
+    mpStyleComboBox->setCurrentIndex(currentIndex);
+  } else {
+    mpStyleComboBox->setCurrentIndex(0);
+  }
+  mpStyleComboBox->blockSignals(state);
+  state = mpFontComboBox->blockSignals(true);
+  QString fontName = queryCommandValue("fontName");
+#ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+  // Remove quotes around the font name.
+  fontName = StringHandler::removeFirstLastQuotes(fontName);
+#else // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+  // Remove single quote around the font name.
+  fontName = StringHandler::removeFirstLastSingleQuotes(fontName);
+#endif // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+  /* Issue #13038
+   * We get the current font name by calling `document.queryCommandValue("fontName")` via JavaScript on current cursor position.
+   * The webkit returns `-webkit-standard` for default font name instead of the actual font name.
+   * When we get `-webkit-standard` convert it to default system font name.
+   */
+  if (fontName.compare(QStringLiteral("-webkit-standard")) == 0) {
+    fontName = Helper::systemFontInfo.family();
+  }
+  currentIndex = mpFontComboBox->findText(fontName, Qt::MatchExactly);
+  if (currentIndex > -1) {
+    mpFontComboBox->setCurrentIndex(currentIndex);
+  }
+  mpFontComboBox->blockSignals(state);
+  bool ok;
+  int fontSize = queryCommandValue("fontSize").toInt(&ok);
+  if (ok) {
+    state = mpFontSizeSpinBox->blockSignals(true);
+    mpFontSizeSpinBox->setValue(fontSize);
+    mpFontSizeSpinBox->blockSignals(state);
+  }
+#ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+  mpBoldAction->setChecked(queryCommandState("bold"));
+  mpItalicAction->setChecked(queryCommandState("italic"));
+  mpUnderlineAction->setChecked(queryCommandState("underline"));
+  mpStrikethroughAction->setChecked(queryCommandState("strikeThrough"));
+  mpSubscriptAction->setChecked(queryCommandState("subscript"));
+  mpSuperscriptAction->setChecked(queryCommandState("superscript"));
+#else // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+  mpBoldAction->setChecked(mpHTMLEditor->pageAction(QWebPage::ToggleBold)->isChecked());
+  mpItalicAction->setChecked(mpHTMLEditor->pageAction(QWebPage::ToggleItalic)->isChecked());
+  mpUnderlineAction->setChecked(mpHTMLEditor->pageAction(QWebPage::ToggleUnderline)->isChecked());
+  mpStrikethroughAction->setChecked(mpHTMLEditor->pageAction(QWebPage::ToggleStrikethrough)->isChecked());
+  mpSubscriptAction->setChecked(mpHTMLEditor->pageAction(QWebPage::ToggleSubscript)->isChecked());
+  mpSuperscriptAction->setChecked(mpHTMLEditor->pageAction(QWebPage::ToggleSuperscript)->isChecked());
+#endif // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+  mpAlignLeftToolButton->setChecked(queryCommandState("justifyLeft"));
+  mpAlignCenterToolButton->setChecked(queryCommandState("justifyCenter"));
+  mpAlignRightToolButton->setChecked(queryCommandState("justifyRight"));
+  mpJustifyToolButton->setChecked(queryCommandState("justifyFull"));
+  mpBulletListAction->setChecked(queryCommandState("insertUnorderedList"));
+  mpNumberedListAction->setChecked(queryCommandState("insertOrderedList"));
+  mpLinkAction->setEnabled(!mpHTMLEditor->page()->selectedText().isEmpty());
+  mpUnLinkAction->setEnabled(!mpHTMLEditor->page()->selectedText().isEmpty() && isLinkSelected());
+}
+
 /*!
  * \brief DocumentationWidget::previousDocumentation
  * Moves to the previous documentation.\n
@@ -927,6 +1056,10 @@ void DocumentationWidget::saveDocumentation(LibraryTreeItem *pNextLibraryTreeIte
         oldDocAnnotationList.append(QString("__OpenModelica_infoHeader=\"%1\"").arg(StringHandler::escapeStringQuotes(documentation.at(2))));
       }
       QString oldDocAnnotationString = QString("annotate=Documentation(%1)").arg(oldDocAnnotationList.join(","));
+      // if we are on html editor tab then update the source before saving the documentation
+      if (mpTabBar->currentIndex() == 0) {
+        updateHTMLSourceEditor();
+      }
       // new documentation annotation
       QList<QString> newDocAnnotationList;
       if (mEditType == EditType::Info) { // if editing the info section
@@ -1004,6 +1137,7 @@ void DocumentationWidget::toggleEditor(int tabIndex)
 {
   switch (tabIndex) {
     case 1:
+      updateHTMLSourceEditor();
       mpHTMLEditorWidget->hide();
       mpHTMLSourceEditor->show();
       mpHTMLSourceEditor->getPlainTextEdit()->setFocus(Qt::ActiveWindowFocusReason);
@@ -1013,6 +1147,9 @@ void DocumentationWidget::toggleEditor(int tabIndex)
       if (mpHTMLSourceEditor->getPlainTextEdit()->document()->isModified()) {
         writeDocumentationFile(mpHTMLSourceEditor->getPlainTextEdit()->toPlainText());
         mpHTMLEditor->setUrl(QUrl::fromLocalFile(mDocumentationFile.fileName()));
+#ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+        updateActions();
+#endif // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
       }
       mpHTMLSourceEditor->hide();
       mpHTMLEditorWidget->show();
@@ -1028,61 +1165,70 @@ void DocumentationWidget::toggleEditor(int tabIndex)
  */
 void DocumentationWidget::updateActions()
 {
-  bool state = mpStyleComboBox->blockSignals(true);
-  QString format = queryCommandValue("formatBlock");
-  int currentIndex = mpStyleComboBox->findData(format);
-  if (currentIndex > -1) {
-    mpStyleComboBox->setCurrentIndex(currentIndex);
-  } else {
-    mpStyleComboBox->setCurrentIndex(0);
-  }
-  mpStyleComboBox->blockSignals(state);
-  state = mpFontComboBox->blockSignals(true);
-  QString fontName = queryCommandValue("fontName");
-  // font name has extra single quote around it so remove it.
-  fontName = StringHandler::removeFirstLastSingleQuotes(fontName);
-  /* Issue #13038
-   * We get the current font name by calling `document.queryCommandValue("fontName")` via JavaScript on current cursor position.
-   * The webkit returns `-webkit-standard` for default font name instead of the actual font name.
-   * When we get `-webkit-standard` convert it to default system font name.
-   */
-  if (fontName.compare(QStringLiteral("-webkit-standard")) == 0) {
-    fontName = Helper::systemFontInfo.family();
-  }
-  currentIndex = mpFontComboBox->findText(fontName, Qt::MatchExactly);
-  if (currentIndex > -1) {
-    mpFontComboBox->setCurrentIndex(currentIndex);
-  }
-  mpFontComboBox->blockSignals(state);
-  bool ok;
-  int fontSize = queryCommandValue("fontSize").toInt(&ok);
-  if (ok) {
-    state = mpFontSizeSpinBox->blockSignals(true);
-    mpFontSizeSpinBox->setValue(fontSize);
-    mpFontSizeSpinBox->blockSignals(state);
-  }
 #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
-  mpBoldAction->setChecked(mpHTMLEditor->pageAction(QWebEnginePage::ToggleBold)->isChecked());
-  mpItalicAction->setChecked(mpHTMLEditor->pageAction(QWebEnginePage::ToggleItalic)->isChecked());
-  mpUnderlineAction->setChecked(mpHTMLEditor->pageAction(QWebEnginePage::ToggleUnderline)->isChecked());
-  mpStrikethroughAction->setChecked(mpHTMLEditor->pageAction(QWebEnginePage::ToggleStrikethrough)->isChecked());
-  // TODO: ToggleSubscript/ToggleSuperscript
-#else
-  mpBoldAction->setChecked(mpHTMLEditor->pageAction(QWebPage::ToggleBold)->isChecked());
-  mpItalicAction->setChecked(mpHTMLEditor->pageAction(QWebPage::ToggleItalic)->isChecked());
-  mpUnderlineAction->setChecked(mpHTMLEditor->pageAction(QWebPage::ToggleUnderline)->isChecked());
-  mpStrikethroughAction->setChecked(mpHTMLEditor->pageAction(QWebPage::ToggleStrikethrough)->isChecked());
-  mpSubscriptAction->setChecked(mpHTMLEditor->pageAction(QWebPage::ToggleSubscript)->isChecked());
-  mpSuperscriptAction->setChecked(mpHTMLEditor->pageAction(QWebPage::ToggleSuperscript)->isChecked());
-#endif
-  mpAlignLeftToolButton->setChecked(queryCommandState("justifyLeft"));
-  mpAlignCenterToolButton->setChecked(queryCommandState("justifyCenter"));
-  mpAlignRightToolButton->setChecked(queryCommandState("justifyRight"));
-  mpJustifyToolButton->setChecked(queryCommandState("justifyFull"));
-  mpBulletListAction->setChecked(queryCommandState("insertUnorderedList"));
-  mpNumberedListAction->setChecked(queryCommandState("insertOrderedList"));
-  mpLinkAction->setEnabled(!mpHTMLEditor->page()->selectedText().isEmpty());
-  mpUnLinkAction->setEnabled(!mpHTMLEditor->page()->selectedText().isEmpty() && isLinkSelected());
+  if (!mpHTMLEditor->page()->hasSelection()) {
+    mpStyleComboBox->setEnabled(false);
+    mpFontComboBox->setEnabled(false);
+    mpFontSizeSpinBox->setEnabled(false);
+    mpBoldAction->setEnabled(false);
+    mpBoldAction->setChecked(false);
+    mpItalicAction->setEnabled(false);
+    mpItalicAction->setChecked(false);
+    mpUnderlineAction->setEnabled(false);
+    mpUnderlineAction->setChecked(false);
+    mpStrikethroughAction->setEnabled(false);
+    mpStrikethroughAction->setChecked(false);
+    mpSubscriptAction->setEnabled(false);
+    mpSubscriptAction->setChecked(false);
+    mpSuperscriptAction->setEnabled(false);
+    mpSuperscriptAction->setChecked(false);
+    mpTextColorToolButton->setEnabled(false);
+    mpBackgroundColorToolButton->setEnabled(false);
+    mpAlignLeftToolButton->setEnabled(false);
+    mpAlignLeftToolButton->setChecked(false);
+    mpAlignCenterToolButton->setEnabled(false);
+    mpAlignCenterToolButton->setChecked(false);
+    mpAlignRightToolButton->setEnabled(false);
+    mpAlignRightToolButton->setChecked(false);
+    mpJustifyToolButton->setEnabled(false);
+    mpJustifyToolButton->setChecked(false);
+    mpDecreaseIndentAction->setEnabled(false);
+    mpIncreaseIndentAction->setEnabled(false);
+    mpBulletListAction->setEnabled(false);
+    mpBulletListAction->setChecked(false);
+    mpNumberedListAction->setEnabled(false);
+    mpNumberedListAction->setChecked(false);
+    mpLinkAction->setEnabled(false);
+    mpLinkAction->setChecked(false);
+    mpUnLinkAction->setEnabled(false);
+    mpUnLinkAction->setChecked(false);
+  } else {
+    mpStyleComboBox->setEnabled(true);
+    mpFontComboBox->setEnabled(true);
+    mpFontSizeSpinBox->setEnabled(true);
+    mpBoldAction->setEnabled(true);
+    mpItalicAction->setEnabled(true);
+    mpUnderlineAction->setEnabled(true);
+    mpStrikethroughAction->setEnabled(true);
+    mpSubscriptAction->setEnabled(true);
+    mpSuperscriptAction->setEnabled(true);
+    mpTextColorToolButton->setEnabled(true);
+    mpBackgroundColorToolButton->setEnabled(true);
+    mpAlignLeftToolButton->setEnabled(true);
+    mpAlignCenterToolButton->setEnabled(true);
+    mpAlignRightToolButton->setEnabled(true);
+    mpJustifyToolButton->setEnabled(true);
+    mpDecreaseIndentAction->setEnabled(true);
+    mpIncreaseIndentAction->setEnabled(true);
+    mpBulletListAction->setEnabled(true);
+    mpNumberedListAction->setEnabled(true);
+    mpLinkAction->setEnabled(true);
+    mpUnLinkAction->setEnabled(true);
+    updateActionsHelper();
+  }
+#else // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+  updateActionsHelper();
+#endif // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
 }
 
 /*!
@@ -1120,6 +1266,24 @@ void DocumentationWidget::fontSize(int size)
 //  execCommand("styleWithCSS", "false");
 }
 
+/*!
+ * \brief DocumentationWidget::subscript
+ * Subscript the text by executing command subscript.
+ */
+void DocumentationWidget::subscript()
+{
+  execCommand("subscript");
+}
+
+/*!
+ * \brief DocumentationWidget::superscript
+ * Superscript the text by executing command superscript.
+ */
+void DocumentationWidget::superscript()
+{
+  execCommand("superscript");
+}
+
 /*!
  * \brief DocumentationWidget::applyTextColor
  * SLOT activated when text color button is clicked.\n
@@ -1237,12 +1401,11 @@ void DocumentationWidget::createLink()
                                "getLinkHref()");
   QString href;
 #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
-  QWebEnginePage *pWebPage = mpHTMLEditor->page();
-  pWebPage->runJavaScript(javaScript, [&](const QVariant & arg){ href = arg.toString(); });
-#else
+  href = runJavaScript(javaScript).toString();
+#else // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
   QWebFrame *pWebFrame = mpHTMLEditor->page()->mainFrame();
   href = pWebFrame->evaluateJavaScript(javaScript).toString();
-#endif
+#endif // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
   href = QInputDialog::getText(this, tr("Create Link"), "Enter URL", QLineEdit::Normal, href);
   execCommand("createLink", href);
 }
@@ -1255,22 +1418,59 @@ void DocumentationWidget::removeLink()
 {
   execCommand("unlink");
 }
+#endif // #ifndef OM_DISABLE_DOCUMENTATION
+
+#ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+DocumentationPage::DocumentationPage(QObject *parent)
+  : QWebEnginePage(parent)
+{
+
+}
 
 /*!
- * \brief DocumentationWidget::updateHTMLSourceEditor
- * Slot activated when QWebView::page() contentsChanged SIGNAL is raised.\n
- * Updates the contents of the HTML source editor.
+ * \brief DocumentationPage::acceptNavigationRequest
+ * Reimplementation of acceptNavigationRequest.
+ * Because you can not delegate all links in QtWebEngine we must override
+ * here and generate our own link requests
+
+ * BUT a loadStarted signal is emitted by this page **before** this is called
+ * Even **before** it knows how we want to handle it!
+ * Once we "return false" from this a loadFinished with okay **false** is generated.
+
+ * These false loadStart and LoadFinished greatly confuse our model
+
+ * Therefore do NOT emit a signal from this method as it can create huge delays in when
+ * loadFinished(okay) returns (with okay as false)
  */
-void DocumentationWidget::updateHTMLSourceEditor()
+bool DocumentationPage::acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame)
 {
-#ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
-  PlainTextEdit *textEdit = mpHTMLSourceEditor->getPlainTextEdit();
-  mpHTMLEditor->page()->toHtml([textEdit](const QString &result){ textEdit->setPlainText(result); });
-#else
-  mpHTMLSourceEditor->getPlainTextEdit()->setPlainText(mpHTMLEditor->page()->mainFrame()->toHtml());
-#endif
+  if ((type == QWebEnginePage::NavigationTypeLinkClicked) || (type == QWebEnginePage::NavigationTypeOther)) {
+    // qDebug() << "acceptNavigationRequest " << url.toString() << " , " << type << " , " << isMainFrame;
+    if (isMainFrame) {
+        mUrl = url;
+        QTimer::singleShot(20,this,SLOT(emitLinkClicked()));
+        return false;
+    }
+    // allow secondary frames such as iframes to be loaded automatically
+    return true;
+  }
+  if (type == QWebEnginePage::NavigationTypeTyped) {
+    // qDebug() << "acceptNavigationRequest from scheme handler load" << url.toString();
+    return true;
+  }
+  if (type == QWebEnginePage::NavigationTypeRedirect) {
+    // qDebug() << "acceptNavigationRequest from scheme handler redirect" << url.toString();
+    return true;
+  }
+  qDebug() << " Unhandled acceptNavigationRequest with type: " << type;
+  return true;
 }
-#endif // #ifndef OM_DISABLE_DOCUMENTATION
+
+void DocumentationPage::emitLinkClicked()
+{
+  emit linkClicked(mUrl);
+}
+#endif // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
 
 /*!
  * \class DocumentationViewer
@@ -1300,6 +1500,9 @@ DocumentationViewer::DocumentationViewer(DocumentationWidget *pDocumentationWidg
   resetZoom();
   // set DocumentationViewer settings
 #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+  // create a new QWebEnginePage so we can handle link clicks
+  mpDocumentationPage = new DocumentationPage(this);
+  setPage(mpDocumentationPage);
   settings()->setFontFamily(QWebEngineSettings::StandardFont, Helper::systemFontInfo.family());
   settings()->setFontSize(QWebEngineSettings::DefaultFontSize, Helper::systemFontInfo.pointSize());
   settings()->setAttribute(QWebEngineSettings::LocalStorageEnabled, true);
@@ -1311,20 +1514,20 @@ DocumentationViewer::DocumentationViewer(DocumentationWidget *pDocumentationWidg
   settings()->setDefaultTextEncoding(Helper::utf8.toUtf8().constData());
   // set DocumentationViewer web page policy
 #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
-  if (isContentEditable)
-    page()->runJavaScript("document.documentElement.contentEditable = true");
-  // TODO: DelegateAllLinks, linkClicked
+  // Set the contenteditable="true" in pageLoaded()
+  /* Qt WebEngine doesn't support DelegateAllLinks, linkClicked
+   * We created an object of QWebEnginePage which overrides acceptNavigationRequest to handle link clicks
+   */
+  connect(page(), SIGNAL(linkClicked(QUrl)), SLOT(processLinkClick(QUrl)));
   connect(page(), SIGNAL(linkHovered(QString)), SLOT(processLinkHover(QString)));
 #else // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
-  page()->setContentEditable(isContentEditable);
+  page()->setContentEditable(mIsContentEditable);
   page()->setLinkDelegationPolicy(QWebPage::DelegateAllLinks);
   connect(page(), SIGNAL(linkClicked(QUrl)), SLOT(processLinkClick(QUrl)));
   connect(page(), SIGNAL(linkHovered(QString,QString,QString)), SLOT(processLinkHover(QString,QString,QString)));
 #endif // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
   createActions();
-  if (!isContentEditable) {
-    connect(this, SIGNAL(loadFinished(bool)), SLOT(pageLoaded(bool)));
-  }
+  connect(this, SIGNAL(loadFinished(bool)), SLOT(pageLoaded(bool)));
 #endif // #ifndef OM_DISABLE_DOCUMENTATION
 }
 
@@ -1479,12 +1682,18 @@ void DocumentationViewer::showContextMenu(QPoint point)
 void DocumentationViewer::pageLoaded(bool ok)
 {
   Q_UNUSED(ok);
-  const QPoint scrollPosition = mpDocumentationWidget->getScrollPosition();
+  if (!mIsContentEditable) {
+    const QPoint scrollPosition = mpDocumentationWidget->getScrollPosition();
 #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
-  page()->runJavaScript(QString("window.scrollTo(%1, %2);").arg(scrollPosition.x()).arg(scrollPosition.y()));
+    page()->runJavaScript(QString("window.scrollTo(%1, %2);").arg(scrollPosition.x()).arg(scrollPosition.y()));
 #else // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
-  page()->mainFrame()->scroll(scrollPosition.x(), scrollPosition.y());
+    page()->mainFrame()->scroll(scrollPosition.x(), scrollPosition.y());
 #endif // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+  } else {
+#ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+    page()->runJavaScript("document.documentElement.contentEditable = true");
+#endif // #ifdef OM_OMEDIT_ENABLE_QTWEBENGINE
+  }
 }
 
 /*!
