@@ -1404,7 +1404,7 @@ namespace ModelInstance
 
   /*!
    * \brief Model::removeElement
-   * Removes the element.
+   * Removes the element from the model and deletes it.
    * \param name
    */
   void Model::removeElement(const QString &name)
@@ -1437,6 +1437,55 @@ namespace ModelInstance
     return comps;
   }
 
+  /*!
+   * \brief Model::removeConnection
+   * Removes the connection from the model and deletes it.
+   * \param pConnection
+   */
+  void Model::removeConnection(const QString &startConnectorName, const QString &endConnectorName)
+  {
+    foreach (auto pConnection, mConnections) {
+      if (pConnection->getStartConnector()->getName().compare(startConnectorName) == 0 && pConnection->getEndConnector()->getName().compare(endConnectorName) == 0) {
+        mConnections.removeOne(pConnection);
+        delete pConnection;
+        break;
+      }
+    }
+  }
+
+  /*!
+   * \brief Model::removeTransition
+   * Removes the transition from the model and deletes it.
+   * \param startConnectorName
+   * \param endConnectorName
+   */
+  void Model::removeTransition(const QString &startConnectorName, const QString &endConnectorName)
+  {
+    foreach (auto pTransition, mTransitions) {
+      if (pTransition->getStartConnector()->getName().compare(startConnectorName) == 0 && pTransition->getEndConnector()->getName().compare(endConnectorName) == 0) {
+        mTransitions.removeOne(pTransition);
+        delete pTransition;
+        break;
+      }
+    }
+  }
+
+  /*!
+   * \brief Model::removeInitialState
+   * Removes the initial state from the model and deletes it.
+   * \param startConnectorName
+   */
+  void Model::removeInitialState(const QString &startConnectorName)
+  {
+    foreach (auto pInitialSate, mInitialStates) {
+      if (pInitialSate->getStartConnector()->getName().compare(startConnectorName) == 0) {
+        mInitialStates.removeOne(pInitialSate);
+        delete pInitialSate;
+        break;
+      }
+    }
+  }
+
   bool Model::isParameterConnectorSizing(const QString &parameter)
   {
     foreach (auto pElement, mElements) {
@@ -2266,7 +2315,10 @@ namespace ModelInstance
     if (jsonObject.contains("value")) {
       QJsonObject valueObject = jsonObject.value("value").toObject();
 
-      if (valueObject.contains("value")) {
+      /* Use "binding" instead of "value"
+       * The binding can either contain the literal value or expression.
+       */
+      /*if (valueObject.contains("value")) {
         try {
           mBinding.deserialize(valueObject.value("value"));
           mBindingForReset = mBinding;
@@ -2274,7 +2326,7 @@ namespace ModelInstance
           qDebug() << "Failed to deserialize json: " << valueObject.value("value");
           qDebug() << e.what();
         }
-      } else if (valueObject.contains("binding")) {
+      } else */if (valueObject.contains("binding")) {
         try {
           mBinding.deserialize(valueObject.value("binding"));
           mBindingForReset = mBinding;
@@ -2625,6 +2677,18 @@ namespace ModelInstance
     mKind = "";
   }
 
+  /*!
+   * \brief Connector::Connector
+   * Constructor for Connector.
+   * \param kind
+   * \param name
+   */
+  Connector::Connector(const QString &kind, const QString &name)
+  {
+    mKind = kind;
+    mName = name;
+  }
+
   void Connector::deserialize(const QJsonObject &jsonObject)
   {
     if (jsonObject.contains("$kind")) {
@@ -2662,6 +2726,23 @@ namespace ModelInstance
     mpParentModel = pParentModel;
   }
 
+  /*!
+   * \brief Connection::Connection
+   * Constructor for Connection.
+   * \param pParentModel
+   * \param startConnector
+   * \param endConnector
+   * \param annotationJsonObject
+   */
+  Connection::Connection(Model *pParentModel, const QString &startConnector, const QString &endConnector, const QJsonObject &annotationJsonObject)
+  {
+    mpParentModel = pParentModel;
+    mpStartConnector = std::make_unique<Connector>("cref", startConnector);
+    mpEndConnector = std::make_unique<Connector>("cref", endConnector);
+    mpAnnotation = std::make_unique<Annotation>(mpParentModel);
+    mpAnnotation->deserialize(annotationJsonObject);
+  }
+
   void Connection::deserialize(const QJsonObject &jsonObject)
   {
     if (jsonObject.contains("lhs")) {
@@ -2700,6 +2781,34 @@ namespace ModelInstance
     mPriority = 1;
   }
 
+  /*!
+   * \brief Transition::Transition
+   * Constructor for Transition.
+   * \param pParentModel
+   * \param startConnector
+   * \param endConnector
+   * \param condition
+   * \param immediate
+   * \param reset
+   * \param synchronize
+   * \param priority
+   * \param annotationJsonObject
+   */
+  Transition::Transition(Model *pParentModel, const QString &startConnector, const QString &endConnector, bool condition, bool immediate, bool reset,
+                         bool synchronize, int priority, const QJsonObject &annotationJsonObject)
+  {
+    mpParentModel = pParentModel;
+    mpStartConnector = std::make_unique<Connector>("cref", startConnector);
+    mpEndConnector = std::make_unique<Connector>("cref", endConnector);
+    mCondition = condition;
+    mImmediate = immediate;
+    mReset = reset;
+    mSynchronize = synchronize;
+    mPriority = priority;
+    mpAnnotation = std::make_unique<Annotation>(mpParentModel);
+    mpAnnotation->deserialize(annotationJsonObject);
+  }
+
   void Transition::deserialize(const QJsonObject &jsonObject)
   {
     if (jsonObject.contains("arguments")) {
@@ -2753,6 +2862,21 @@ namespace ModelInstance
     mpParentModel = pParentModel;
   }
 
+  /*!
+   * \brief InitialState::InitialState
+   * Constructor for InitialState.
+   * \param pParentModel
+   * \param startConnector
+   * \param annotationJsonObject
+   */
+  InitialState::InitialState(Model *pParentModel, const QString &startConnector, const QJsonObject &annotationJsonObject)
+  {
+    mpParentModel = pParentModel;
+    mpStartConnector = std::make_unique<Connector>("cref", startConnector);
+    mpAnnotation = std::make_unique<Annotation>(mpParentModel);
+    mpAnnotation->deserialize(annotationJsonObject);
+  }
+
   void InitialState::deserialize(const QJsonObject &jsonObject)
   {
     if (jsonObject.contains("arguments")) {
