@@ -63,12 +63,14 @@ DiagramWindow::DiagramWindow(QWidget *parent) : QWidget(parent)
  */
 void DiagramWindow::showVisualizationDiagram(ModelWidget *pModelWidget)
 {
-  if (pModelWidget && pModelWidget->getDiagramGraphicsView() && pModelWidget->getLibraryTreeItem()->getLibraryType() == LibraryTreeItem::Modelica) {
+  if (pModelWidget && pModelWidget->getDiagramGraphicsView() && pModelWidget->getLibraryTreeItem()->isModelica()) {
     setWindowTitle(pModelWidget->getLibraryTreeItem()->getName());
     mpModelWidget = pModelWidget;
     mpModelWidget->getDiagramGraphicsView()->setIsVisualizationView(true);
     connect(MainWindow::instance()->getVariablesWidget(), SIGNAL(updateDynamicSelect(double)),
             mpModelWidget->getDiagramGraphicsView(), SIGNAL(updateDynamicSelect(double)), Qt::UniqueConnection);
+    connect(MainWindow::instance()->getVariablesWidget(), SIGNAL(resetDynamicSelect()),
+            mpModelWidget->getDiagramGraphicsView(), SIGNAL(resetDynamicSelect()), Qt::UniqueConnection);
     mpModelWidget->getDiagramGraphicsView()->show();
     mpMainLayout->addWidget(mpModelWidget->getDiagramGraphicsView());
   } else {
@@ -87,6 +89,8 @@ void DiagramWindow::removeVisualizationDiagram()
     setWindowTitle("Diagram");
     disconnect(MainWindow::instance()->getVariablesWidget(), SIGNAL(updateDynamicSelect(double)),
                mpModelWidget->getDiagramGraphicsView(), SIGNAL(updateDynamicSelect(double)));
+    disconnect(MainWindow::instance()->getVariablesWidget(), SIGNAL(resetDynamicSelect()),
+               mpModelWidget->getDiagramGraphicsView(), SIGNAL(resetDynamicSelect()));
     mpMainLayout->removeWidget(mpModelWidget->getDiagramGraphicsView());
     mpModelWidget = 0;
   }
